@@ -253,11 +253,7 @@ class readNmea():
                 elif res1=='GSV':
                     print(res)
                     x=GPGSVrec(res)
-                    self.print=("Number of Messages1: "+x.nofmsg+" Message Number: "+x.msgno+" Satellites in View: "+x.sinV+
-                                  " Satellite ID Ch1: "+x.idch1+" Elevation (degree) Ch1: "+x.evch1+" Azimuth (degree) ch1: "+x.azch1+" SNR ch1 (dBHz): "+x.snrch1+
-                                  " Satellite ID Ch2: "+x.idch2+" Elevation (degree) Ch2: "+x.evch2+" Azimuth (degree) ch2: "+x.azch2+" SNR ch2 (dBHz): "+x.snrch2+
-                                  " Satellite ID Ch3: "+x.idch3+" Elevation (degree) Ch3: "+x.evch3+" Azimuth (degree) ch3: "+x.azch3+" SNR ch3 (dBHz): "+x.snrch3+
-                                  " Satellite ID Ch4: "+x.idch4+" Elevation (degree) Ch4: "+x.evch4+" Azimuth (degree) ch4: "+x.azch4+" SNR ch4 (dBHz): "+x.snrch4+"\n")
+                    print("Number of Messages1: "+x.nofmsg+" Message Number: "+x.msgno+" Satellites in View: "+x.sinV+" Satellite ID Ch1: "+x.idch1+" Elevation (degree) Ch1: "+x.evch1+" Azimuth (degree) ch1: "+x.azch1+" SNR ch1 (dBHz): "+x.snrch1+" Satellite ID Ch2: "+x.idch2+" Elevation (degree) Ch2: "+x.evch2+" Azimuth (degree) ch2: "+x.azch2+" SNR ch2 (dBHz): "+x.snrch2+" Satellite ID Ch3: "+x.idch3+" Elevation (degree) Ch3: "+x.evch3+" Azimuth (degree) ch3: "+x.azch3+" SNR ch3 (dBHz): "+x.snrch3+" Satellite ID Ch4: "+x.idch4+" Elevation (degree) Ch4: "+x.evch4+" Azimuth (degree) ch4: "+x.azch4+" SNR ch4 (dBHz): "+x.snrch4+"\n")
                     
 
 #$GPGGA,124632.122,5231.537,N,01320.203,E,1,12,1.0,0.0,M,0.0,M,,*6A
